/* IMPORTANT
 * This snapshot file is auto-generated, but designed for humans.
 * It should be checked into source control and tracked carefully.
 * Re-generate by setting TAP_SNAPSHOT=1 and running tests.
 * Make sure to inspect the output below.  Do not ignore changes!
 */
'use strict'
exports[`test/types/index.ts TAP > types are there 1`] = `
Array [
  Object {
    "identify": Function identify(value),
    "resolve": Function resolve(str),
    "tag": "!re",
  },
  Object {
    "identify": Function identify(value),
    "resolve": Function resolve(str),
    "stringify": Function stringify(item, ctx, onComment, onChompKeep),
    "tag": "!symbol/shared",
  },
  Object {
    "identify": Function identify(value),
    "resolve": Function resolve(str),
    "stringify": Function stringify(item, ctx, onComment, onChompKeep),
    "tag": "!symbol",
  },
  Object {
    "identify": Function identify(value),
    "resolve": Function resolve(str),
    "stringify": Function stringify(item, ctx, onComment, onChompKeep),
    "tag": "!bigint",
  },
  Object {
    "collection": "map",
    "identify": Function identify(v),
    "nodeClass": Function YAMLNullObject(classYAMLNullObjectextendsyaml_1.YAMLMap),
    "tag": "!nullobject",
  },
  Object {
    "collection": "map",
    "identify": Function identify(er),
    "nodeClass": Function YAMLErrorObject(classYAMLErrorObjectextendsyaml_1.YAMLMap),
    "tag": "!error",
  },
  Object {
    "identify": Function identify(value),
    "options": Object {
      "defaultType": "BLOCK_LITERAL",
    },
    "resolve": Function resolve(str),
    "stringify": Function stringify(i, ctx, onComment, onChompKeep),
    "tag": "!class",
  },
  Object {
    "identify": Function identify(value),
    "options": Object {
      "defaultType": "BLOCK_LITERAL",
    },
    "resolve": Function resolve(str),
    "stringify": Function stringify(i, ctx, onComment, onChompKeep),
    "tag": "!function",
  },
  Object {
    "default": false,
    "identify": Function identify(value),
    "resolve": Function resolve(str),
    "stringify": Function stringify(),
    "tag": "tag:yaml.org,2002:timestamp",
    "test": /^([0-9]{4})-([0-9]{1,2})-([0-9]{1,2})(?:(?:t|T|[ \\t]+)([0-9]{1,2}):([0-9]{1,2}):([0-9]{1,2}(\\.[0-9]+)?)(?:[ \\t]*(Z|[-+][012]?[0-9](?::[0-9]{2})?))?)?$/,
  },
  Object {
    "identify": Function identify(),
    "resolve": Function resolve(src),
    "tag": "!date",
  },
  "omap",
  "set",
  "binary",
]
`
